ADTF Python Package
===================

Installation
------------

### Binary Packages

Binary packages are provided for Linux (x86_64 and aarch64) and Windows (x86_64) for Python versions 3.9 and up.

```bash
pip install adtf
```

### Building from the source distribution

If you cannot obtain a binary package for your platform/python version you can build the package from source.
You therefore need:

- a working C/C++ compiler toolchain,
- an installed **ADTF runtime package** and an installed **ADTF sdk package** (both at least version `3.21.0`).

#### Linux

```bash
adtf_sdk_DIR="<path to your ADTF sdk package>" adtf_runtime_DIR="<path to your ADTF runtime package>" pip install adtf
```

#### Windows

```cmd.exe
cmd /C (set adtf_sdk_DIR="<path to your ADTF sdk package>" && set adtf_runtime_DIR="<path to your ADTF runtime package>" && pip install adtf)
```

Python Modules
-------

This package provides the following modules:

- [adtf](doc/adtf_python_module.md)
- [adtf_file](doc/adtf_file_python_module.md)

ADTF File Plugins
-------

This packlage provides the following ADTF File plugins:

- [adtf_file_python_processor](doc/adtf_file_python_processor.md)

License
-------

This package uses the [MPL-2.0](LICENSE.md) license.

Release Notes
-------------

The release notes can be found at [RELEASENOTES.md](RELEASENOTES.md).